package net.knarcraft.paidsigns.command;

import net.knarcraft.paidsigns.PaidSigns;
import net.knarcraft.paidsigns.container.PaidSign;
import net.knarcraft.paidsigns.manager.PaidSignManager;
import net.knarcraft.paidsigns.property.OptionState;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.io.IOException;
import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * A representation of the command for adding a new match condition for a sign
 */
public class AddConditionCommand extends TokenizedCommand {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        super.onCommand(sender, command, label, args);
        if (argumentSize < 3) {
            return false;
        }

        String name = arguments.get(0);
        short lineNumber;
        try {
            lineNumber = (short) (Short.parseShort(arguments.get(1)) - 1);
        } catch (NumberFormatException exception) {
            sender.sendMessage("Invalid line number given");
            return false;
        }
        String stringToMatch = arguments.get(2);
        boolean executeRegEx = false;
        if (argumentSize > 3) {
            executeRegEx = Boolean.parseBoolean(arguments.get(3));
        }
        OptionState ignoreCase = OptionState.DEFAULT;
        if (argumentSize > 4) {
            ignoreCase = OptionState.getFromBoolean(Boolean.parseBoolean(arguments.get(4)));
        }
        OptionState ignoreColor = OptionState.DEFAULT;
        if (argumentSize > 5) {
            ignoreColor = OptionState.getFromBoolean(Boolean.parseBoolean(arguments.get(5)));
        }
        PaidSignManager signManager = PaidSigns.getInstance().getSignManager();
        PaidSign sign = signManager.getPaidSign(name);
        if (sign == null) {
            sender.sendMessage("No such paid sign exists");
            return false;
        }
        sign.addCondition(lineNumber, stringToMatch, executeRegEx, ignoreCase, ignoreColor);
        try {
            signManager.saveSigns();
        } catch (IOException e) {
            Logger logger = PaidSigns.getInstance().getLogger();
            logger.log(Level.SEVERE, "Exception encountered while trying to write to the data file");
            logger.log(Level.SEVERE, Arrays.toString(e.getStackTrace()));
            sender.sendMessage("An exception occurred. Please notify the server administrator or check the server log.");
            return false;
        }
        sender.sendMessage("Condition added");
        return true;
    }

}
